# Pythno Short Link Extractor

## Install

```shell
pip install -U shortlink-extractor
```

## Usage

example

```python
from shortlink_extractor import extract_short_link

originalURL = extract_short_link("https://bit.ly/******")
```
